History
-------

1.0
~~~

2018-12-02

- Move to hyo2 namespace


0.5
~~~

2018-06-21

- Bug fix to follow GDAL-convention for geotransform

2018-04-08

- Switch to git

2017-04-21

- Switch to Python 3


0.2
~~~

2016-05-27

- Added option to read a slice of rows for elevation and uncertainty layers

2016-03-21

- Added option to reproject layers into user-defined EPSG


2015-10-24

- Split BAG Explorer as stand-alone hydro-package


2015-10-09

- Added BAG Explorer
- Started Schematron schema for BAG Metadata profile


0.1
~~~

2015-03-31

- Initial commit.
